# NAME

WWW::OpenAPIClient::Role - a Moose role for the API League

API League is a Hub for World Class APIs.

# VERSION

Automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.6.4
- Package version: 1.0.0
- Generator version: 7.8.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.PerlClientCodegen

## A note on Moose

This role is the only component of the library that uses Moose. See
WWW::OpenAPIClient::ApiFactory for non-Moosey usage.

# SYNOPSIS

The Perl Generator in the OpenAPI Generator project builds a library of Perl modules to interact with
a web service defined by a OpenAPI Specification. See below for how to build the
library.

This module provides an interface to the generated library. All the classes,
objects, and methods (well, not quite \*all\*, see below) are flattened into this
role.

        package MyApp;
        use Moose;
        with 'WWW::OpenAPIClient::Role';

        package main;

        my $api = MyApp->new({ tokens => $tokens });

        my $pet = $api->get_pet_by_id(pet_id => $pet_id);


## Structure of the library

The library consists of a set of API classes, one for each endpoint. These APIs
implement the method calls available on each endpoint.

Additionally, there is a set of "object" classes, which represent the objects
returned by and sent to the methods on the endpoints.

An API factory class is provided, which builds instances of each endpoint API.

This Moose role flattens all the methods from the endpoint APIs onto the consuming
class. It also provides methods to retrieve the endpoint API objects, and the API
factory object, should you need it.

For documentation of all these methods, see AUTOMATIC DOCUMENTATION below.

## Configuring authentication

In the normal case, the OpenAPI Spec will describe what parameters are
required and where to put them. You just need to supply the tokens.

    my $tokens = {
        # basic
        username => $username,
        password => $password,

        # oauth
        access_token => $oauth_token,

        # keys
        $some_key => { token => $token,
                       prefix => $prefix,
                       in => $in,             # 'head||query',
                       },

        $another => { token => $token,
                      prefix => $prefix,
                      in => $in,              # 'head||query',
                      },
        ...,

        };

        my $api = MyApp->new({ tokens => $tokens });

Note these are all optional, as are `prefix` and `in`, and depend on the API
you are accessing. Usually `prefix` and `in` will be determined by the code generator from
the spec and you will not need to set them at run time. If not, `in` will
default to 'head' and `prefix` to the empty string.

The tokens will be placed in a L<WWW::OpenAPIClient::Configuration> instance
as follows, but you don't need to know about this.

- `$cfg->{username}`

    String. The username for basic auth.

- `$cfg->{password}`

    String. The password for basic auth.

- `$cfg->{api_key}`

    Hashref. Keyed on the name of each key (there can be multiple tokens).

            $cfg->{api_key} = {
                    secretKey => 'aaaabbbbccccdddd',
                    anotherKey => '1111222233334444',
                    };

- `$cfg->{api_key_prefix}`

    Hashref. Keyed on the name of each key (there can be multiple tokens). Note not
    all api keys require a prefix.

            $cfg->{api_key_prefix} = {
                    secretKey => 'string',
                    anotherKey => 'same or some other string',
                    };

- `$cfg->{access_token}`

    String. The OAuth access token.

# METHODS

## `base_url`

The generated code has the `base_url` already set as a default value. This method
returns the current value of `base_url`.

## `api_factory`

Returns an API factory object. You probably won't need to call this directly.

        $self->api_factory('Pet'); # returns a WWW::OpenAPIClient::PetApi instance

        $self->pet_api;            # the same

# MISSING METHODS

Most of the methods on the API are delegated to individual endpoint API objects
(e.g. Pet API, Store API, User API etc). Where different endpoint APIs use the
same method name (e.g. `new()`), these methods can't be delegated. So you need
to call `$api->pet_api->new()`.

In principle, every API is susceptible to the presence of a few, random, undelegatable
method names. In practice, because of the way method names are constructed, it's
unlikely in general that any methods will be undelegatable, except for:

        new()
        class_documentation()
        method_documentation()

To call these methods, you need to get a handle on the relevant object, either
by calling `$api->foo_api` or by retrieving an object, e.g.
`$api->get_pet_by_id(pet_id => $pet_id)`. They are class methods, so
you could also call them on class names.

# BUILDING YOUR LIBRARY

See the homepage `https://openapi-generator.tech` for full details.
But briefly, clone the git repository, build the codegen codebase, set up your build
config file, then run the API build script. You will need git, Java 7 or 8 and Apache
maven 3.0.3 or better already installed.

The config file should specify the project name for the generated library:

        {"moduleName":"WWW::MyProjectName"}

Your library files will be built under `WWW::MyProjectName`.

          $ git clone https://github.com/openapitools/openapi-generator
          $ cd openapi-generator
          $ mvn package
          $ java -jar modules/openapi-generator-cli/target/openapi-generator-cli.jar generate \
    -i [URL or file path to JSON OpenAPI API spec] \
    -g perl \
    -c /path/to/config/file.json \
    -o /path/to/output/folder

Bang, all done. Run the `autodoc` script in the `bin` directory to see the API
you just built.

# AUTOMATIC DOCUMENTATION

You can print out a summary of the generated API by running the included
`autodoc` script in the `bin` directory of your generated library. A few
output formats are supported:

          Usage: autodoc [OPTION]

    -w           wide format (default)
    -n           narrow format
    -p           POD format
    -H           HTML format
    -m           Markdown format
    -h           print this help message
    -c           your application class


The `-c` option allows you to load and inspect your own application. A dummy
namespace is used if you don't supply your own class.

# DOCUMENTATION FROM THE OpenAPI Spec

Additional documentation for each class and method may be provided by the OpenAPI
spec. If so, this is available via the `class_documentation()` and
`method_documentation()` methods on each generated object class, and the
`method_documentation()` method on the endpoint API classes:

        my $cmdoc = $api->pet_api->method_documentation->{$method_name};

        my $odoc = $api->get_pet_by_id->(pet_id => $pet_id)->class_documentation;
        my $omdoc = $api->get_pet_by_id->(pet_id => $pet_id)->method_documentation->{method_name};


Each of these calls returns a hashref with various useful pieces of information.

# Installation Prerequisites

Use [cpanm](https://metacpan.org/pod/distribution/App-cpanminus/bin/cpanm) to install the module dependencies:

```
cpanm --local-lib=~/perl5 local::lib && eval $(perl -I ~/perl5/lib/perl5/ -Mlocal::lib)
cpanm --quiet --no-interactive Class::Accessor Test::Exception Test::More Log::Any LWP::UserAgent URI::Query Module::Runtime DateTime Module::Find Moose::Role JSON
```

# LOAD THE MODULES

To load the API packages:
```perl
use WWW::OpenAPIClient::ArtApi;
use WWW::OpenAPIClient::BooksApi;
use WWW::OpenAPIClient::FoodApi;
use WWW::OpenAPIClient::HumorApi;
use WWW::OpenAPIClient::KnowledgeApi;
use WWW::OpenAPIClient::MathApi;
use WWW::OpenAPIClient::MediaApi;
use WWW::OpenAPIClient::NewsApi;
use WWW::OpenAPIClient::StorageApi;
use WWW::OpenAPIClient::TextApi;
use WWW::OpenAPIClient::WebApi;

```

To load the models:
```perl
use WWW::OpenAPIClient::Object::ComputeNutritionAPI200Response;
use WWW::OpenAPIClient::Object::ComputeNutritionAPI200ResponseIngredientBreakdownInner;
use WWW::OpenAPIClient::Object::ComputeNutritionAPI200ResponseIngredientBreakdownInnerNutrientsInner;
use WWW::OpenAPIClient::Object::ConvertUnitsAPI200Response;
use WWW::OpenAPIClient::Object::CorrectSpellingAPI200Response;
use WWW::OpenAPIClient::Object::DetectGenderByNameAPI200Response;
use WWW::OpenAPIClient::Object::DetectLanguageAPI200ResponseInner;
use WWW::OpenAPIClient::Object::DetectMainImageColorAPI200ResponseInner;
use WWW::OpenAPIClient::Object::DetectSentimentAPI200Response;
use WWW::OpenAPIClient::Object::DetectSentimentAPI200ResponseDocument;
use WWW::OpenAPIClient::Object::DetectSentimentAPI200ResponseSentencesInner;
use WWW::OpenAPIClient::Object::ExtractAuthorsAPI200Response;
use WWW::OpenAPIClient::Object::ExtractAuthorsAPI200ResponseAuthorsInner;
use WWW::OpenAPIClient::Object::ExtractContentFromAWebPageAPI200Response;
use WWW::OpenAPIClient::Object::ExtractDatesAPI200Response;
use WWW::OpenAPIClient::Object::ExtractDatesAPI200ResponseDatesInner;
use WWW::OpenAPIClient::Object::ExtractEntitiesAPI200Response;
use WWW::OpenAPIClient::Object::ExtractEntitiesAPI200ResponseEntitiesInner;
use WWW::OpenAPIClient::Object::ExtractNewsAPI200Response;
use WWW::OpenAPIClient::Object::ExtractNewsAPI200ResponseImagesInner;
use WWW::OpenAPIClient::Object::ExtractNewsAPI200ResponseVideosInner;
use WWW::OpenAPIClient::Object::ExtractPublishDateAPI200Response;
use WWW::OpenAPIClient::Object::FindSimilarBooksAPI200Response;
use WWW::OpenAPIClient::Object::GenerateNonsenseWordAPI200Response;
use WWW::OpenAPIClient::Object::ListWordSynonymsAPI200Response;
use WWW::OpenAPIClient::Object::PluralizeWordAPI200Response;
use WWW::OpenAPIClient::Object::RandomMemeAPI200Response;
use WWW::OpenAPIClient::Object::RandomPoemAPI200Response;
use WWW::OpenAPIClient::Object::RandomQuoteAPI200Response;
use WWW::OpenAPIClient::Object::RandomRiddleAPI200Response;
use WWW::OpenAPIClient::Object::RandomTriviaAPI200Response;
use WWW::OpenAPIClient::Object::ReadKeyValueFromStoreAPI200Response;
use WWW::OpenAPIClient::Object::RetrievePageRankAPI200Response;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200Response;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseCredits;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseDietaryProperties;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseIngredientsInner;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseIngredientsInnerMeasures;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseInstructionsInner;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseInstructionsInnerStepsInner;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseNutrition;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseNutritionIngredientBreakdownInner;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseScores;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseTaste;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseTimes;
use WWW::OpenAPIClient::Object::ScoreReadabilityAPI200Response;
use WWW::OpenAPIClient::Object::ScoreTextAPI200Response;
use WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseInterestingness;
use WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseInterestingnessSubscores;
use WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseReadability;
use WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseReadabilityMainscores;
use WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseReadabilitySubscores;
use WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseSkimmability;
use WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseSkimmabilityMainscores;
use WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseSkimmabilitySubscores;
use WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseStyle;
use WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseStyleSubscores;
use WWW::OpenAPIClient::Object::SearchBooksAPI200Response;
use WWW::OpenAPIClient::Object::SearchBooksAPI200ResponseBooksInnerInner;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200Response;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInner;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerCredits;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerIngredientsInner;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasures;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresMetric;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresUs;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerInstructionsInner;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInner;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInnerIngredientsInner;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerNutrition;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerNutritionCaloricBreakdown;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerNutritionFlavonoidsInner;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInner;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInnerNutrientsInner;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerNutritionNutrientsInner;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerNutritionWeightPerServing;
use WWW::OpenAPIClient::Object::SearchGifsAPI200Response;
use WWW::OpenAPIClient::Object::SearchGifsAPI200ResponseImagesInner;
use WWW::OpenAPIClient::Object::SearchIconsAPI200Response;
use WWW::OpenAPIClient::Object::SearchJokesAPI200Response;
use WWW::OpenAPIClient::Object::SearchJokesAPI200ResponseJokesInner;
use WWW::OpenAPIClient::Object::SearchMemesAPI200Response;
use WWW::OpenAPIClient::Object::SearchMemesAPI200ResponseMemesInner;
use WWW::OpenAPIClient::Object::SearchNewsAPI200Response;
use WWW::OpenAPIClient::Object::SearchNewsAPI200ResponseNewsInner;
use WWW::OpenAPIClient::Object::SearchRecipesAPI200Response;
use WWW::OpenAPIClient::Object::SearchRecipesAPI200ResponseRecipesInner;
use WWW::OpenAPIClient::Object::SearchRecipesAPI200ResponseRecipesInnerNutrition;
use WWW::OpenAPIClient::Object::SearchRecipesAPI200ResponseRecipesInnerNutritionNutrientsInner;
use WWW::OpenAPIClient::Object::SearchRestaurantsAPI200Response;
use WWW::OpenAPIClient::Object::SearchRestaurantsAPI200ResponseRestaurantsInner;
use WWW::OpenAPIClient::Object::SearchRestaurantsAPI200ResponseRestaurantsInnerAddress;
use WWW::OpenAPIClient::Object::SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHours;
use WWW::OpenAPIClient::Object::SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHoursOperational;
use WWW::OpenAPIClient::Object::SearchRoyaltyFreeImagesAPI200Response;
use WWW::OpenAPIClient::Object::SearchRoyaltyFreeImagesAPI200ResponseImagesInner;
use WWW::OpenAPIClient::Object::SearchRoyaltyFreeImagesAPI200ResponseImagesInnerLicense;
use WWW::OpenAPIClient::Object::SearchWebAPI200Response;
use WWW::OpenAPIClient::Object::SearchWebAPI200ResponseResultsInner;
use WWW::OpenAPIClient::Object::SingularizeWordAPI200Response;
use WWW::OpenAPIClient::Object::StemTextAPI200Response;
use WWW::OpenAPIClient::Object::StoreKeyValueGETAPI200Response;
use WWW::OpenAPIClient::Object::TagPartOfSpeechAPI200Response;
use WWW::OpenAPIClient::Object::TopNewsAPI200Response;
use WWW::OpenAPIClient::Object::TopNewsAPI200ResponseTopNewsInner;
use WWW::OpenAPIClient::Object::TopNewsAPI200ResponseTopNewsInnerNewsInner;
use WWW::OpenAPIClient::Object::VectorSearchAPI200Response;
use WWW::OpenAPIClient::Object::VectorSearchAPI200ResponseVectorsInner;
use WWW::OpenAPIClient::Object::VerifyEmailAddressAPI200Response;

````

# GETTING STARTED
Put the Perl SDK under the 'lib' folder in your project directory, then run the following
```perl
#!/usr/bin/perl
use lib 'lib';
use strict;
use warnings;
# load the API package
use WWW::OpenAPIClient::ArtApi;
use WWW::OpenAPIClient::BooksApi;
use WWW::OpenAPIClient::FoodApi;
use WWW::OpenAPIClient::HumorApi;
use WWW::OpenAPIClient::KnowledgeApi;
use WWW::OpenAPIClient::MathApi;
use WWW::OpenAPIClient::MediaApi;
use WWW::OpenAPIClient::NewsApi;
use WWW::OpenAPIClient::StorageApi;
use WWW::OpenAPIClient::TextApi;
use WWW::OpenAPIClient::WebApi;

# load the models
use WWW::OpenAPIClient::Object::ComputeNutritionAPI200Response;
use WWW::OpenAPIClient::Object::ComputeNutritionAPI200ResponseIngredientBreakdownInner;
use WWW::OpenAPIClient::Object::ComputeNutritionAPI200ResponseIngredientBreakdownInnerNutrientsInner;
use WWW::OpenAPIClient::Object::ConvertUnitsAPI200Response;
use WWW::OpenAPIClient::Object::CorrectSpellingAPI200Response;
use WWW::OpenAPIClient::Object::DetectGenderByNameAPI200Response;
use WWW::OpenAPIClient::Object::DetectLanguageAPI200ResponseInner;
use WWW::OpenAPIClient::Object::DetectMainImageColorAPI200ResponseInner;
use WWW::OpenAPIClient::Object::DetectSentimentAPI200Response;
use WWW::OpenAPIClient::Object::DetectSentimentAPI200ResponseDocument;
use WWW::OpenAPIClient::Object::DetectSentimentAPI200ResponseSentencesInner;
use WWW::OpenAPIClient::Object::ExtractAuthorsAPI200Response;
use WWW::OpenAPIClient::Object::ExtractAuthorsAPI200ResponseAuthorsInner;
use WWW::OpenAPIClient::Object::ExtractContentFromAWebPageAPI200Response;
use WWW::OpenAPIClient::Object::ExtractDatesAPI200Response;
use WWW::OpenAPIClient::Object::ExtractDatesAPI200ResponseDatesInner;
use WWW::OpenAPIClient::Object::ExtractEntitiesAPI200Response;
use WWW::OpenAPIClient::Object::ExtractEntitiesAPI200ResponseEntitiesInner;
use WWW::OpenAPIClient::Object::ExtractNewsAPI200Response;
use WWW::OpenAPIClient::Object::ExtractNewsAPI200ResponseImagesInner;
use WWW::OpenAPIClient::Object::ExtractNewsAPI200ResponseVideosInner;
use WWW::OpenAPIClient::Object::ExtractPublishDateAPI200Response;
use WWW::OpenAPIClient::Object::FindSimilarBooksAPI200Response;
use WWW::OpenAPIClient::Object::GenerateNonsenseWordAPI200Response;
use WWW::OpenAPIClient::Object::ListWordSynonymsAPI200Response;
use WWW::OpenAPIClient::Object::PluralizeWordAPI200Response;
use WWW::OpenAPIClient::Object::RandomMemeAPI200Response;
use WWW::OpenAPIClient::Object::RandomPoemAPI200Response;
use WWW::OpenAPIClient::Object::RandomQuoteAPI200Response;
use WWW::OpenAPIClient::Object::RandomRiddleAPI200Response;
use WWW::OpenAPIClient::Object::RandomTriviaAPI200Response;
use WWW::OpenAPIClient::Object::ReadKeyValueFromStoreAPI200Response;
use WWW::OpenAPIClient::Object::RetrievePageRankAPI200Response;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200Response;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseCredits;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseDietaryProperties;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseIngredientsInner;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseIngredientsInnerMeasures;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseInstructionsInner;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseInstructionsInnerStepsInner;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseNutrition;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseNutritionIngredientBreakdownInner;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseScores;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseTaste;
use WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseTimes;
use WWW::OpenAPIClient::Object::ScoreReadabilityAPI200Response;
use WWW::OpenAPIClient::Object::ScoreTextAPI200Response;
use WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseInterestingness;
use WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseInterestingnessSubscores;
use WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseReadability;
use WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseReadabilityMainscores;
use WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseReadabilitySubscores;
use WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseSkimmability;
use WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseSkimmabilityMainscores;
use WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseSkimmabilitySubscores;
use WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseStyle;
use WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseStyleSubscores;
use WWW::OpenAPIClient::Object::SearchBooksAPI200Response;
use WWW::OpenAPIClient::Object::SearchBooksAPI200ResponseBooksInnerInner;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200Response;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInner;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerCredits;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerIngredientsInner;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasures;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresMetric;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresUs;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerInstructionsInner;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInner;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInnerIngredientsInner;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerNutrition;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerNutritionCaloricBreakdown;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerNutritionFlavonoidsInner;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInner;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInnerNutrientsInner;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerNutritionNutrientsInner;
use WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerNutritionWeightPerServing;
use WWW::OpenAPIClient::Object::SearchGifsAPI200Response;
use WWW::OpenAPIClient::Object::SearchGifsAPI200ResponseImagesInner;
use WWW::OpenAPIClient::Object::SearchIconsAPI200Response;
use WWW::OpenAPIClient::Object::SearchJokesAPI200Response;
use WWW::OpenAPIClient::Object::SearchJokesAPI200ResponseJokesInner;
use WWW::OpenAPIClient::Object::SearchMemesAPI200Response;
use WWW::OpenAPIClient::Object::SearchMemesAPI200ResponseMemesInner;
use WWW::OpenAPIClient::Object::SearchNewsAPI200Response;
use WWW::OpenAPIClient::Object::SearchNewsAPI200ResponseNewsInner;
use WWW::OpenAPIClient::Object::SearchRecipesAPI200Response;
use WWW::OpenAPIClient::Object::SearchRecipesAPI200ResponseRecipesInner;
use WWW::OpenAPIClient::Object::SearchRecipesAPI200ResponseRecipesInnerNutrition;
use WWW::OpenAPIClient::Object::SearchRecipesAPI200ResponseRecipesInnerNutritionNutrientsInner;
use WWW::OpenAPIClient::Object::SearchRestaurantsAPI200Response;
use WWW::OpenAPIClient::Object::SearchRestaurantsAPI200ResponseRestaurantsInner;
use WWW::OpenAPIClient::Object::SearchRestaurantsAPI200ResponseRestaurantsInnerAddress;
use WWW::OpenAPIClient::Object::SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHours;
use WWW::OpenAPIClient::Object::SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHoursOperational;
use WWW::OpenAPIClient::Object::SearchRoyaltyFreeImagesAPI200Response;
use WWW::OpenAPIClient::Object::SearchRoyaltyFreeImagesAPI200ResponseImagesInner;
use WWW::OpenAPIClient::Object::SearchRoyaltyFreeImagesAPI200ResponseImagesInnerLicense;
use WWW::OpenAPIClient::Object::SearchWebAPI200Response;
use WWW::OpenAPIClient::Object::SearchWebAPI200ResponseResultsInner;
use WWW::OpenAPIClient::Object::SingularizeWordAPI200Response;
use WWW::OpenAPIClient::Object::StemTextAPI200Response;
use WWW::OpenAPIClient::Object::StoreKeyValueGETAPI200Response;
use WWW::OpenAPIClient::Object::TagPartOfSpeechAPI200Response;
use WWW::OpenAPIClient::Object::TopNewsAPI200Response;
use WWW::OpenAPIClient::Object::TopNewsAPI200ResponseTopNewsInner;
use WWW::OpenAPIClient::Object::TopNewsAPI200ResponseTopNewsInnerNewsInner;
use WWW::OpenAPIClient::Object::VectorSearchAPI200Response;
use WWW::OpenAPIClient::Object::VectorSearchAPI200ResponseVectorsInner;
use WWW::OpenAPIClient::Object::VerifyEmailAddressAPI200Response;

# for displaying the API response data
use Data::Dumper;


my $api_instance = WWW::OpenAPIClient::ArtApi->new(
    # Configure API key authorization: apiKey
    api_key => {'api-key' => 'YOUR_API_KEY'},
    # uncomment below to setup prefix (e.g. Bearer) for API key, if needed
    #api_key_prefix => {'api-key' => 'Bearer'},
    # Configure API key authorization: headerApiKey
    api_key => {'x-api-key' => 'YOUR_API_KEY'},
    # uncomment below to setup prefix (e.g. Bearer) for API key, if needed
    #api_key_prefix => {'x-api-key' => 'Bearer'},
);

my $url = https://upload.wikimedia.org/wikipedia/commons/3/35/Basic_human_drawing.png; # string | The URL to the image.
my $width = 200; # int | The maximum width of the image (default 400, max. 500).
my $height = 200; # int | The maximum height of the image (default 400, max. 500).

eval {
    my $result = $api_instance->image_to_ascii_art_by_urlapi(url => $url, width => $width, height => $height);
    print Dumper($result);
};
if ($@) {
    warn "Exception when calling ArtApi->image_to_ascii_art_by_urlapi: $@\n";
}

```

# DOCUMENTATION FOR API ENDPOINTS

All URIs are relative to *https://api.apileague.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ArtApi* | [**image_to_ascii_art_by_urlapi**](docs/ArtApi.md#image_to_ascii_art_by_urlapi) | **GET** /convert-image-to-ascii-txt | Image to Ascii Art by URL API
*ArtApi* | [**random_poem_api**](docs/ArtApi.md#random_poem_api) | **GET** /retrieve-random-poem | Random Poem API
*BooksApi* | [**find_similar_books_api**](docs/BooksApi.md#find_similar_books_api) | **GET** /list-similar-books | Find Similar Books API
*BooksApi* | [**search_books_api**](docs/BooksApi.md#search_books_api) | **GET** /search-books | Search Books API
*FoodApi* | [**compute_nutrition_api**](docs/FoodApi.md#compute_nutrition_api) | **GET** /compute-nutrition | Compute Nutrition API
*FoodApi* | [**retrieve_recipe_information_api**](docs/FoodApi.md#retrieve_recipe_information_api) | **GET** /retrieve-recipe | Retrieve Recipe Information API
*FoodApi* | [**search_drinks_api**](docs/FoodApi.md#search_drinks_api) | **GET** /search-drinks | Search Drinks API
*FoodApi* | [**search_recipes_api**](docs/FoodApi.md#search_recipes_api) | **GET** /search-recipes | Search Recipes API
*FoodApi* | [**search_restaurants_api**](docs/FoodApi.md#search_restaurants_api) | **GET** /search-restaurants | Search Restaurants API
*HumorApi* | [**generate_nonsense_word_api**](docs/HumorApi.md#generate_nonsense_word_api) | **GET** /generate-nonsense-word | Generate Nonsense Word API
*HumorApi* | [**random_joke_api**](docs/HumorApi.md#random_joke_api) | **GET** /retrieve-random-joke | Random Joke API
*HumorApi* | [**random_meme_api**](docs/HumorApi.md#random_meme_api) | **GET** /retrieve-random-meme | Random Meme API
*HumorApi* | [**search_gifs_api**](docs/HumorApi.md#search_gifs_api) | **GET** /search-gifs | Search Gifs API
*HumorApi* | [**search_jokes_api**](docs/HumorApi.md#search_jokes_api) | **GET** /search-jokes | Search Jokes API
*HumorApi* | [**search_memes_api**](docs/HumorApi.md#search_memes_api) | **GET** /search-memes | Search Memes API
*KnowledgeApi* | [**random_quote_api**](docs/KnowledgeApi.md#random_quote_api) | **GET** /retrieve-random-quote | Random Quote API
*KnowledgeApi* | [**random_riddle_api**](docs/KnowledgeApi.md#random_riddle_api) | **GET** /retrieve-random-riddle | Random Riddle API
*KnowledgeApi* | [**random_trivia_api**](docs/KnowledgeApi.md#random_trivia_api) | **GET** /retrieve-random-trivia | Random Trivia API
*MathApi* | [**convert_units_api**](docs/MathApi.md#convert_units_api) | **GET** /convert-units | Convert Units API
*MediaApi* | [**detect_main_image_color_api**](docs/MediaApi.md#detect_main_image_color_api) | **GET** /detect-color | Detect Main Image Color API
*MediaApi* | [**rescale_image_api**](docs/MediaApi.md#rescale_image_api) | **GET** /rescale-image | Rescale Image API
*MediaApi* | [**search_icons_api**](docs/MediaApi.md#search_icons_api) | **GET** /search-icons | Search Icons API
*MediaApi* | [**search_royalty_free_images_api**](docs/MediaApi.md#search_royalty_free_images_api) | **GET** /search-images | Search Royalty Free Images API
*MediaApi* | [**vector_search_api**](docs/MediaApi.md#vector_search_api) | **GET** /search-vectors | Vector Search API
*NewsApi* | [**extract_news_api**](docs/NewsApi.md#extract_news_api) | **GET** /extract-news | Extract News API
*NewsApi* | [**search_news_api**](docs/NewsApi.md#search_news_api) | **GET** /search-news | Search News API
*NewsApi* | [**top_news_api**](docs/NewsApi.md#top_news_api) | **GET** /retrieve-top-news | Top News API
*StorageApi* | [**read_key_value_from_store_api**](docs/StorageApi.md#read_key_value_from_store_api) | **GET** /read-key-value | Read Key Value from Store API
*StorageApi* | [**store_key_value_getapi**](docs/StorageApi.md#store_key_value_getapi) | **GET** /store-key-value | Store Key Value (GET) API
*TextApi* | [**correct_spelling_api**](docs/TextApi.md#correct_spelling_api) | **GET** /correct-spelling | Correct Spelling API
*TextApi* | [**detect_gender_by_name_api**](docs/TextApi.md#detect_gender_by_name_api) | **GET** /detect-gender | Detect Gender by Name API
*TextApi* | [**detect_language_api**](docs/TextApi.md#detect_language_api) | **GET** /detect-language | Detect Language API
*TextApi* | [**detect_sentiment_api**](docs/TextApi.md#detect_sentiment_api) | **GET** /detect-sentiment | Detect Sentiment API
*TextApi* | [**extract_dates_api**](docs/TextApi.md#extract_dates_api) | **GET** /extract-dates | Extract Dates API
*TextApi* | [**extract_entities_api**](docs/TextApi.md#extract_entities_api) | **GET** /extract-entities | Extract Entities API
*TextApi* | [**list_word_synonyms_api**](docs/TextApi.md#list_word_synonyms_api) | **GET** /list-synonyms | List Word Synonyms API
*TextApi* | [**pluralize_word_api**](docs/TextApi.md#pluralize_word_api) | **GET** /pluralize-word | Pluralize Word API
*TextApi* | [**score_readability_api**](docs/TextApi.md#score_readability_api) | **GET** /score-readability | Score Readability API
*TextApi* | [**score_text_api**](docs/TextApi.md#score_text_api) | **GET** /score-text | Score Text API
*TextApi* | [**singularize_word_api**](docs/TextApi.md#singularize_word_api) | **GET** /singularize-word | Singularize Word API
*TextApi* | [**stem_text_api**](docs/TextApi.md#stem_text_api) | **GET** /stem-text | Stem Text API
*TextApi* | [**tag_part_of_speech_api**](docs/TextApi.md#tag_part_of_speech_api) | **GET** /tag-pos | Tag Part of Speech API
*WebApi* | [**extract_authors_api**](docs/WebApi.md#extract_authors_api) | **GET** /extract-authors | Extract Authors API
*WebApi* | [**extract_content_from_a_web_page_api**](docs/WebApi.md#extract_content_from_a_web_page_api) | **GET** /extract-content | Extract Content from a Web Page API
*WebApi* | [**extract_publish_date_api**](docs/WebApi.md#extract_publish_date_api) | **GET** /extract-publish-date | Extract Publish Date API
*WebApi* | [**retrieve_page_rank_api**](docs/WebApi.md#retrieve_page_rank_api) | **GET** /retrieve-page-rank | Retrieve Page Rank API
*WebApi* | [**search_web_api**](docs/WebApi.md#search_web_api) | **GET** /search-web | Search Web API
*WebApi* | [**verify_email_address_api**](docs/WebApi.md#verify_email_address_api) | **GET** /verify-email | Verify Email Address API


# DOCUMENTATION FOR MODELS
 - [WWW::OpenAPIClient::Object::ComputeNutritionAPI200Response](docs/ComputeNutritionAPI200Response.md)
 - [WWW::OpenAPIClient::Object::ComputeNutritionAPI200ResponseIngredientBreakdownInner](docs/ComputeNutritionAPI200ResponseIngredientBreakdownInner.md)
 - [WWW::OpenAPIClient::Object::ComputeNutritionAPI200ResponseIngredientBreakdownInnerNutrientsInner](docs/ComputeNutritionAPI200ResponseIngredientBreakdownInnerNutrientsInner.md)
 - [WWW::OpenAPIClient::Object::ConvertUnitsAPI200Response](docs/ConvertUnitsAPI200Response.md)
 - [WWW::OpenAPIClient::Object::CorrectSpellingAPI200Response](docs/CorrectSpellingAPI200Response.md)
 - [WWW::OpenAPIClient::Object::DetectGenderByNameAPI200Response](docs/DetectGenderByNameAPI200Response.md)
 - [WWW::OpenAPIClient::Object::DetectLanguageAPI200ResponseInner](docs/DetectLanguageAPI200ResponseInner.md)
 - [WWW::OpenAPIClient::Object::DetectMainImageColorAPI200ResponseInner](docs/DetectMainImageColorAPI200ResponseInner.md)
 - [WWW::OpenAPIClient::Object::DetectSentimentAPI200Response](docs/DetectSentimentAPI200Response.md)
 - [WWW::OpenAPIClient::Object::DetectSentimentAPI200ResponseDocument](docs/DetectSentimentAPI200ResponseDocument.md)
 - [WWW::OpenAPIClient::Object::DetectSentimentAPI200ResponseSentencesInner](docs/DetectSentimentAPI200ResponseSentencesInner.md)
 - [WWW::OpenAPIClient::Object::ExtractAuthorsAPI200Response](docs/ExtractAuthorsAPI200Response.md)
 - [WWW::OpenAPIClient::Object::ExtractAuthorsAPI200ResponseAuthorsInner](docs/ExtractAuthorsAPI200ResponseAuthorsInner.md)
 - [WWW::OpenAPIClient::Object::ExtractContentFromAWebPageAPI200Response](docs/ExtractContentFromAWebPageAPI200Response.md)
 - [WWW::OpenAPIClient::Object::ExtractDatesAPI200Response](docs/ExtractDatesAPI200Response.md)
 - [WWW::OpenAPIClient::Object::ExtractDatesAPI200ResponseDatesInner](docs/ExtractDatesAPI200ResponseDatesInner.md)
 - [WWW::OpenAPIClient::Object::ExtractEntitiesAPI200Response](docs/ExtractEntitiesAPI200Response.md)
 - [WWW::OpenAPIClient::Object::ExtractEntitiesAPI200ResponseEntitiesInner](docs/ExtractEntitiesAPI200ResponseEntitiesInner.md)
 - [WWW::OpenAPIClient::Object::ExtractNewsAPI200Response](docs/ExtractNewsAPI200Response.md)
 - [WWW::OpenAPIClient::Object::ExtractNewsAPI200ResponseImagesInner](docs/ExtractNewsAPI200ResponseImagesInner.md)
 - [WWW::OpenAPIClient::Object::ExtractNewsAPI200ResponseVideosInner](docs/ExtractNewsAPI200ResponseVideosInner.md)
 - [WWW::OpenAPIClient::Object::ExtractPublishDateAPI200Response](docs/ExtractPublishDateAPI200Response.md)
 - [WWW::OpenAPIClient::Object::FindSimilarBooksAPI200Response](docs/FindSimilarBooksAPI200Response.md)
 - [WWW::OpenAPIClient::Object::GenerateNonsenseWordAPI200Response](docs/GenerateNonsenseWordAPI200Response.md)
 - [WWW::OpenAPIClient::Object::ListWordSynonymsAPI200Response](docs/ListWordSynonymsAPI200Response.md)
 - [WWW::OpenAPIClient::Object::PluralizeWordAPI200Response](docs/PluralizeWordAPI200Response.md)
 - [WWW::OpenAPIClient::Object::RandomMemeAPI200Response](docs/RandomMemeAPI200Response.md)
 - [WWW::OpenAPIClient::Object::RandomPoemAPI200Response](docs/RandomPoemAPI200Response.md)
 - [WWW::OpenAPIClient::Object::RandomQuoteAPI200Response](docs/RandomQuoteAPI200Response.md)
 - [WWW::OpenAPIClient::Object::RandomRiddleAPI200Response](docs/RandomRiddleAPI200Response.md)
 - [WWW::OpenAPIClient::Object::RandomTriviaAPI200Response](docs/RandomTriviaAPI200Response.md)
 - [WWW::OpenAPIClient::Object::ReadKeyValueFromStoreAPI200Response](docs/ReadKeyValueFromStoreAPI200Response.md)
 - [WWW::OpenAPIClient::Object::RetrievePageRankAPI200Response](docs/RetrievePageRankAPI200Response.md)
 - [WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200Response](docs/RetrieveRecipeInformationAPI200Response.md)
 - [WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseCredits](docs/RetrieveRecipeInformationAPI200ResponseCredits.md)
 - [WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseDietaryProperties](docs/RetrieveRecipeInformationAPI200ResponseDietaryProperties.md)
 - [WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseIngredientsInner](docs/RetrieveRecipeInformationAPI200ResponseIngredientsInner.md)
 - [WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseIngredientsInnerMeasures](docs/RetrieveRecipeInformationAPI200ResponseIngredientsInnerMeasures.md)
 - [WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseInstructionsInner](docs/RetrieveRecipeInformationAPI200ResponseInstructionsInner.md)
 - [WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseInstructionsInnerStepsInner](docs/RetrieveRecipeInformationAPI200ResponseInstructionsInnerStepsInner.md)
 - [WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseNutrition](docs/RetrieveRecipeInformationAPI200ResponseNutrition.md)
 - [WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseNutritionIngredientBreakdownInner](docs/RetrieveRecipeInformationAPI200ResponseNutritionIngredientBreakdownInner.md)
 - [WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseScores](docs/RetrieveRecipeInformationAPI200ResponseScores.md)
 - [WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseTaste](docs/RetrieveRecipeInformationAPI200ResponseTaste.md)
 - [WWW::OpenAPIClient::Object::RetrieveRecipeInformationAPI200ResponseTimes](docs/RetrieveRecipeInformationAPI200ResponseTimes.md)
 - [WWW::OpenAPIClient::Object::ScoreReadabilityAPI200Response](docs/ScoreReadabilityAPI200Response.md)
 - [WWW::OpenAPIClient::Object::ScoreTextAPI200Response](docs/ScoreTextAPI200Response.md)
 - [WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseInterestingness](docs/ScoreTextAPI200ResponseInterestingness.md)
 - [WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseInterestingnessSubscores](docs/ScoreTextAPI200ResponseInterestingnessSubscores.md)
 - [WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseReadability](docs/ScoreTextAPI200ResponseReadability.md)
 - [WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseReadabilityMainscores](docs/ScoreTextAPI200ResponseReadabilityMainscores.md)
 - [WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseReadabilitySubscores](docs/ScoreTextAPI200ResponseReadabilitySubscores.md)
 - [WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseSkimmability](docs/ScoreTextAPI200ResponseSkimmability.md)
 - [WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseSkimmabilityMainscores](docs/ScoreTextAPI200ResponseSkimmabilityMainscores.md)
 - [WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseSkimmabilitySubscores](docs/ScoreTextAPI200ResponseSkimmabilitySubscores.md)
 - [WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseStyle](docs/ScoreTextAPI200ResponseStyle.md)
 - [WWW::OpenAPIClient::Object::ScoreTextAPI200ResponseStyleSubscores](docs/ScoreTextAPI200ResponseStyleSubscores.md)
 - [WWW::OpenAPIClient::Object::SearchBooksAPI200Response](docs/SearchBooksAPI200Response.md)
 - [WWW::OpenAPIClient::Object::SearchBooksAPI200ResponseBooksInnerInner](docs/SearchBooksAPI200ResponseBooksInnerInner.md)
 - [WWW::OpenAPIClient::Object::SearchDrinksAPI200Response](docs/SearchDrinksAPI200Response.md)
 - [WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInner](docs/SearchDrinksAPI200ResponseDrinksInner.md)
 - [WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerCredits](docs/SearchDrinksAPI200ResponseDrinksInnerCredits.md)
 - [WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerIngredientsInner](docs/SearchDrinksAPI200ResponseDrinksInnerIngredientsInner.md)
 - [WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasures](docs/SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasures.md)
 - [WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresMetric](docs/SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresMetric.md)
 - [WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresUs](docs/SearchDrinksAPI200ResponseDrinksInnerIngredientsInnerMeasuresUs.md)
 - [WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerInstructionsInner](docs/SearchDrinksAPI200ResponseDrinksInnerInstructionsInner.md)
 - [WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInner](docs/SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInner.md)
 - [WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInnerIngredientsInner](docs/SearchDrinksAPI200ResponseDrinksInnerInstructionsInnerStepsInnerIngredientsInner.md)
 - [WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerNutrition](docs/SearchDrinksAPI200ResponseDrinksInnerNutrition.md)
 - [WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerNutritionCaloricBreakdown](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionCaloricBreakdown.md)
 - [WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerNutritionFlavonoidsInner](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionFlavonoidsInner.md)
 - [WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInner](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInner.md)
 - [WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInnerNutrientsInner](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionIngredientBreakdownInnerNutrientsInner.md)
 - [WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerNutritionNutrientsInner](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionNutrientsInner.md)
 - [WWW::OpenAPIClient::Object::SearchDrinksAPI200ResponseDrinksInnerNutritionWeightPerServing](docs/SearchDrinksAPI200ResponseDrinksInnerNutritionWeightPerServing.md)
 - [WWW::OpenAPIClient::Object::SearchGifsAPI200Response](docs/SearchGifsAPI200Response.md)
 - [WWW::OpenAPIClient::Object::SearchGifsAPI200ResponseImagesInner](docs/SearchGifsAPI200ResponseImagesInner.md)
 - [WWW::OpenAPIClient::Object::SearchIconsAPI200Response](docs/SearchIconsAPI200Response.md)
 - [WWW::OpenAPIClient::Object::SearchJokesAPI200Response](docs/SearchJokesAPI200Response.md)
 - [WWW::OpenAPIClient::Object::SearchJokesAPI200ResponseJokesInner](docs/SearchJokesAPI200ResponseJokesInner.md)
 - [WWW::OpenAPIClient::Object::SearchMemesAPI200Response](docs/SearchMemesAPI200Response.md)
 - [WWW::OpenAPIClient::Object::SearchMemesAPI200ResponseMemesInner](docs/SearchMemesAPI200ResponseMemesInner.md)
 - [WWW::OpenAPIClient::Object::SearchNewsAPI200Response](docs/SearchNewsAPI200Response.md)
 - [WWW::OpenAPIClient::Object::SearchNewsAPI200ResponseNewsInner](docs/SearchNewsAPI200ResponseNewsInner.md)
 - [WWW::OpenAPIClient::Object::SearchRecipesAPI200Response](docs/SearchRecipesAPI200Response.md)
 - [WWW::OpenAPIClient::Object::SearchRecipesAPI200ResponseRecipesInner](docs/SearchRecipesAPI200ResponseRecipesInner.md)
 - [WWW::OpenAPIClient::Object::SearchRecipesAPI200ResponseRecipesInnerNutrition](docs/SearchRecipesAPI200ResponseRecipesInnerNutrition.md)
 - [WWW::OpenAPIClient::Object::SearchRecipesAPI200ResponseRecipesInnerNutritionNutrientsInner](docs/SearchRecipesAPI200ResponseRecipesInnerNutritionNutrientsInner.md)
 - [WWW::OpenAPIClient::Object::SearchRestaurantsAPI200Response](docs/SearchRestaurantsAPI200Response.md)
 - [WWW::OpenAPIClient::Object::SearchRestaurantsAPI200ResponseRestaurantsInner](docs/SearchRestaurantsAPI200ResponseRestaurantsInner.md)
 - [WWW::OpenAPIClient::Object::SearchRestaurantsAPI200ResponseRestaurantsInnerAddress](docs/SearchRestaurantsAPI200ResponseRestaurantsInnerAddress.md)
 - [WWW::OpenAPIClient::Object::SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHours](docs/SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHours.md)
 - [WWW::OpenAPIClient::Object::SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHoursOperational](docs/SearchRestaurantsAPI200ResponseRestaurantsInnerLocalHoursOperational.md)
 - [WWW::OpenAPIClient::Object::SearchRoyaltyFreeImagesAPI200Response](docs/SearchRoyaltyFreeImagesAPI200Response.md)
 - [WWW::OpenAPIClient::Object::SearchRoyaltyFreeImagesAPI200ResponseImagesInner](docs/SearchRoyaltyFreeImagesAPI200ResponseImagesInner.md)
 - [WWW::OpenAPIClient::Object::SearchRoyaltyFreeImagesAPI200ResponseImagesInnerLicense](docs/SearchRoyaltyFreeImagesAPI200ResponseImagesInnerLicense.md)
 - [WWW::OpenAPIClient::Object::SearchWebAPI200Response](docs/SearchWebAPI200Response.md)
 - [WWW::OpenAPIClient::Object::SearchWebAPI200ResponseResultsInner](docs/SearchWebAPI200ResponseResultsInner.md)
 - [WWW::OpenAPIClient::Object::SingularizeWordAPI200Response](docs/SingularizeWordAPI200Response.md)
 - [WWW::OpenAPIClient::Object::StemTextAPI200Response](docs/StemTextAPI200Response.md)
 - [WWW::OpenAPIClient::Object::StoreKeyValueGETAPI200Response](docs/StoreKeyValueGETAPI200Response.md)
 - [WWW::OpenAPIClient::Object::TagPartOfSpeechAPI200Response](docs/TagPartOfSpeechAPI200Response.md)
 - [WWW::OpenAPIClient::Object::TopNewsAPI200Response](docs/TopNewsAPI200Response.md)
 - [WWW::OpenAPIClient::Object::TopNewsAPI200ResponseTopNewsInner](docs/TopNewsAPI200ResponseTopNewsInner.md)
 - [WWW::OpenAPIClient::Object::TopNewsAPI200ResponseTopNewsInnerNewsInner](docs/TopNewsAPI200ResponseTopNewsInnerNewsInner.md)
 - [WWW::OpenAPIClient::Object::VectorSearchAPI200Response](docs/VectorSearchAPI200Response.md)
 - [WWW::OpenAPIClient::Object::VectorSearchAPI200ResponseVectorsInner](docs/VectorSearchAPI200ResponseVectorsInner.md)
 - [WWW::OpenAPIClient::Object::VerifyEmailAddressAPI200Response](docs/VerifyEmailAddressAPI200Response.md)


# DOCUMENTATION FOR AUTHORIZATION

Authentication schemes defined for the API:
## apiKey

- **Type**: API key
- **API key parameter name**: api-key
- **Location**: URL query string

## headerApiKey

- **Type**: API key
- **API key parameter name**: x-api-key
- **Location**: HTTP header

